@@ -59,19 +59,8 @@ NodeExpressionParser::NodeExpressionParser() {
     }
 
     QStringList attrNames;
-    attrNames << "meter"
-              << "event"
-              << "repeat"
-              << "trigger"
-              << "label"
-              << "time"
-              << "date"
-              << "late"
-              << "limit"
-              << "limit"
-              << "limiter"
-              << "var"
-              << "genvar";
+    attrNames << "meter" << "event" << "repeat" << "trigger" << "label" << "time" << "date" << "late" << "limit"
+              << "limiter" << "var" << "genvar" << "mirror" << "aviso";
     Q_FOREACH (QString s, attrNames) {
         VAttributeType* t = VAttributeType::find(s.toStdString());
         Q_ASSERT(t);
@@ -121,10 +110,8 @@ bool NodeExpressionParser::isEnvVar(const std::string& str) const {
 }
 
 bool NodeExpressionParser::isNodeHasAttribute(const std::string& str) const {
-    if (str == "has_triggers" || str == "has_time" || str == "has_date" || str == "locked")
-        return true;
-
-    return false;
+    constexpr std::array searchable = {"has_triggers", "has_time", "has_date", "locked", "has_aviso", "has_mirror"};
+    return std::find(searchable.begin(), searchable.end(), str) != searchable.end();
 }
 
 bool NodeExpressionParser::isNodeFlag(const std::string& str) const {
@@ -137,18 +124,30 @@ bool NodeExpressionParser::isNodeFlag(const std::string& str) const {
 }
 
 bool NodeExpressionParser::isWhatToSearchIn(const std::string& str, bool& isAttr) const {
-    // list of non-attribute items that we can search in
-    if (str == "node_name" || str == "node_path") {
+
+    constexpr auto is_searchable_nonattribute = [](const std::string& str) {
+        static constexpr std::array searchable = {"node_name", "node_path"};
+        return std::find(searchable.begin(), searchable.end(), str) != searchable.end();
+    };
+
+    constexpr auto is_searchable_attribute = [](const std::string& str) {
+        static constexpr std::array searchable = {
+            "var_name",           "var_value",          "var_type",           "label_name",  "label_value",
+            "meter_name",         "meter_value",        "event_name",         "event_value", "date_name",
+            "time_name",          "limit_name",         "limit_value",        "limit_max",   "limiter_name",
+            "repeat_name",        "repeat_value",       "trigger_expression", "mirror_name", "mirror_remote_path",
+            "mirror_remote_host", "mirror_remote_port", "mirror_polling",     "aviso_name",  "aviso_listener",
+            "aviso_url",          "aviso_schema",       "aviso_polling",      "aviso_auth"};
+        return std::find(searchable.begin(), searchable.end(), str) != searchable.end();
+    };
+
+    if (is_searchable_nonattribute(str)) {
         isAttr = false;
         return true;
     }
 
     // list of attributes that we can search in
-    else if (str == "var_name" || str == "var_value" || str == "var_type" || str == "label_name" ||
-             str == "label_value" || str == "meter_name" || str == "meter_value" || str == "event_name" ||
-             str == "event_value" || str == "date_name" || str == "time_name" || str == "limit_name" ||
-             str == "limit_value" || str == "limit_max" || str == "limiter_name" || str == "repeat_name" ||
-             str == "repeat_value" || str == "trigger_expression") {
+    else if (is_searchable_attribute(str)) {
         isAttr = true;
         return true;
     }
@@ -818,6 +817,12 @@ bool NodeAttributeCondition::execute(VItem* item) {
         else if (nodeAttrName_ == "has_triggers") {
             return (node->triggerAst() || node->completeAst());
         }
+        else if (nodeAttrName_ == "has_aviso") {
+            return !node->avisos().empty();
+        }
+        else if (nodeAttrName_ == "has_mirror") {
+            return !node->mirrors().empty();
+        }
     }
 
     return false;
