@@ -172,6 +172,8 @@ protected:
 
     virtual void renderMeter(QPainter* painter, QStringList data, const QStyleOptionViewItem& option, QSize&) const;
     virtual void renderLabel(QPainter* painter, QStringList data, const QStyleOptionViewItem& option, QSize&) const;
+    virtual void renderAviso(QPainter* painter, QStringList data, const QStyleOptionViewItem& option, QSize&) const;
+    virtual void renderMirror(QPainter* painter, QStringList data, const QStyleOptionViewItem& option, QSize&) const;
     virtual void renderEvent(QPainter* painter, QStringList data, const QStyleOptionViewItem& option, QSize&) const;
     virtual void renderVar(QPainter* painter, QStringList data, const QStyleOptionViewItem& option, QSize&) const;
     virtual void renderGenvar(QPainter* painter, QStringList data, const QStyleOptionViewItem& option, QSize&) const;
@@ -245,6 +247,8 @@ protected:
     QPen holdingTimeFontPen_;
     QPen holdingDateFontPen_;
 
+    int avisoPixId_;
+    int mirrorPixId_;
     int holdingTimePixId_;
     int holdingDatePixId_;
 
